LineSegmentPath class

A list of Linesegments which consists of segments in screen-pixels.

Constructors

LineSegmentPath()

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
segments → List<LineSegment>
final

Methods

extractPart(double startDistance, double endDistance) → LineSegmentPath
Creates a new LineString that consists of only the part between startDistance and endDistance.
getBounds() → MapRectangle
interpolate(double distance) → Mappoint?
Interpolates on the segment and returns the coordinate of the interpolation result. Returns null if distance is < 0 or > length().
length() → double
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reducePathForText(double textWidth, double repeatStart, double repeatGap) → LineSegmentPath
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Properties

MAX_LABEL_CORNER_ANGLE → double
final