RenderInfoNode<T extends Renderinstruction> class

Inheritance

Constructors

RenderInfoNode(NodeProperties nodeProperties, T renderinstruction, {double rotateRadians = 0, String? caption})

Properties

boundaryAbsolute ↔ MapRectangle?
getter/setter pairinherited
caption → String?
The caption to draw. (used by renderinstructionCaption and renderinstructionPathtext)
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
nodeProperties → NodeProperties
final
renderInstruction → T
finalinherited
rotateRadians → double
used for linesymbol and polyline_text
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shapePainter ↔ ShapePainter<T>?
The painter to use for this renderinstruction.
getter/setter pairinherited

Methods

clashesWith(RenderInfo<Renderinstruction> other) → bool
override
getBoundaryAbsolute() → MapRectangle
override
intersects(MapRectangle other) → bool
Returns true if the current shape intersects with the given rectangle. This is used to find out if the current shape also needs to be drawn at a neighboring shape.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(RenderContext renderContext) → void
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited