RenderInfoWay<T extends Renderinstruction> class

In the terminal window run

flutter packages pub run build_runner build --delete-conflicting-outputs
Inheritance

Constructors

RenderInfoWay(WayProperties wayProperties, T renderInstruction, {String? caption})

Properties

boundaryAbsolute ↔ MapRectangle?
getter/setter pairinherited
caption → String?
The caption to draw. (used by renderinstructionCaption and renderinstructionPathtext)
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
renderInstruction → T
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shapePainter ↔ ShapePainter<T>?
The painter to use for this renderinstruction.
getter/setter pairinherited
wayProperties → WayProperties
final

Methods

clashesWith(RenderInfo<Renderinstruction> other) → bool
Returns if MapElementContainers clash with each other
override
getBoundaryAbsolute() → MapRectangle
override
intersects(MapRectangle other) → bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(RenderContext renderContext) → void
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited