StyleMenu class

Model for Mapsforge RenderTheme <stylemenu>.

A <stylemenu> defines a set of layers (and their categories / overlays) which can be toggled by the host application.

Documentation: https://github.com/mapsforge/mapsforge/blob/master/docs/Rendertheme.md#stylemenus

Constructors

StyleMenu({required String id, String? defaultValue, String? defaultLang, required List<StyleMenuLayer> layers})
const

Properties

defaultLang String?
The default language for localized layer names.
final
defaultValue String?
The default layer id to be selected.
final
enabledLayers List<StyleMenuLayer>
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
The unique identifier of the style menu.
final
layers List<StyleMenuLayer>
All layer definitions contained in this menu.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
visibleLayers List<StyleMenuLayer>
no setter

Methods

categoriesForDefault() Set<String>
Returns all categories which are enabled by their respective layers. This is used if no layer is specified by default
categoriesForLayer(StyleMenuLayer layer) Set<String>
categoriesForLayerId(String layerId) Set<String>
layerById(String id) StyleMenuLayer?
Returns the layer with the given id, or null if it does not exist.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited