layerById method
Returns the layer with the given id, or null if it does not exist.
Implementation
StyleMenuLayer? layerById(String id) {
for (final layer in layers) {
if (layer.id == id) return layer;
}
return null;
}
Returns the layer with the given id, or null if it does not exist.
StyleMenuLayer? layerById(String id) {
for (final layer in layers) {
if (layer.id == id) return layer;
}
return null;
}