StyleMenuLayer class

Represents a <layer> element inside a Mapsforge RenderTheme <stylemenu>.

A layer groups multiple categories (<cat id="..."/>) and/or overlay layers (<overlay id="..."/>) to be toggled together.

Documentation: https://github.com/mapsforge/mapsforge/blob/master/docs/Rendertheme.md#stylemenus

Constructors

StyleMenuLayer({required String id, bool? enabled, bool? visible, String? parent, required List<StyleMenuTranslation> names, required List<String> categories, required List<String> overlays})

Properties

categories → List<String>
Category ids controlled by this layer.
final
enabled → bool?
Whether this layer should be enabled by default.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
Unique layer identifier.
final
names → List<StyleMenuTranslation>
Localized names of this layer.
final
overlays → List<String>
Overlay layer ids referenced by this layer.
final
parent → String?
Optional parent layer id.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
visible → bool?
Whether this layer should be visible to the user (i.e. shown in a UI).
final

Methods

nameForLang(String lang, {String? fallbackLang}) → String?
Returns the best matching localized name.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited