enabled property
Whether this layer should be enabled by default.
XML: <layer enabled="true|false">
If this attribute is not present, this value is null.
Implementation
final bool? enabled;
Whether this layer should be enabled by default.
XML: <layer enabled="true|false">
If this attribute is not present, this value is null.
final bool? enabled;