visible property

bool? visible
final

Whether this layer should be visible to the user (i.e. shown in a UI).

XML: <layer visible="true|false">

Mapsforge uses visible="true" for user-selectable styles and visible="false" for internal/base layers.

If this attribute is not present, this value is null.

Implementation

final bool? visible;