StyleMenuTranslation class

Represents a localized <name> entry inside a Mapsforge RenderTheme <stylemenu>/<layer>.

Documentation: https://github.com/mapsforge/mapsforge/blob/master/docs/Rendertheme.md#stylemenus

Constructors

StyleMenuTranslation({required String lang, required String value})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
lang String
Language code for the translation, e.g. en, de, it.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
Translated display value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited