getBoundary abstract method
Returns the boundary of this object around the center of the area or the poi. If the boundary cannot determined exactly we need to estimate it. This method is used only if the renderinstruction adds itself to label or clash (see LayerContainer) and to determine if the object has been tapped by the user
Implementation
MapRectangle getBoundary(RenderInfo renderInfo);