RuleAnalyzer class

Analyzes the given rules to identify the specific tags that influence the output. Put another way, if a node or way does not possess these identified tags, it will not be considered for rendering.

Inheritance

Constructors

RuleAnalyzer()

Properties

closedWays → ElementInfo
final
debug → bool
final
hashCode → int
The hash code for this object.
no setterinherited
keys → Set<String>
final
nodes → ElementInfo
final
openWays → ElementInfo
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addClosedWay(Rule rule) → void
addNode(Rule rule) → void
addOpenWay(Rule rule) → void
analyzeRule(Rule rule, int level) → void
apply(Rule r) → void
override
closedWayNegativeValueinfos() → Map<String, ValueInfo>
closedWayValueinfos() → Map<String, ValueInfo>
nodeNegativeValueinfos() → Map<String, ValueInfo>
nodeValueinfos() → Map<String, ValueInfo>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openWayNegativeValueinfos() → Map<String, ValueInfo>
openWayValueinfos() → Map<String, ValueInfo>
toString() → String
A string representation of this object.
inherited
wayNegativeValueinfos() → Map<String, ValueInfo>
wayValueinfos() → Map<String, ValueInfo>

Operators

operator ==(Object other) → bool
The equality operator.
inherited