setCategories method

void setCategories(
  1. Set<String>? categories
)

Sets the categories used for rendering. Rules can have a category parameter. When a list of categories is set with this method rules which do not match the categories will not be rendered. See also https://github.com/mapsforge/mapsforge/blob/master/docs/Rendertheme.md#stylemenus

Implementation

void setCategories(Set<String>? categories) {
  _categories = categories;
  if (_categories != null && _categories!.isEmpty) _categories = null;
  for (var element in _renderthemeZoomlevels.values) {
    element.dispose();
  }
  _renderthemeZoomlevels.clear();
}