Methods
-
apply(RuleVisitor v)
→ void
-
-
forZoomlevel(int zoomlevel, Set<String>? categories, int Function())
→ Rule?
-
-
getZoomlevelRangeClosedWay(ITagCollection tags)
→ ZoomlevelRange?
-
Returns the widest possible zoomrange which may accept the given argument.
Returns null if if the argument will never accepted.
-
getZoomlevelRangeNode(ITagCollection tags)
→ ZoomlevelRange?
-
Returns the widest possible zoomrange which may accept the given argument.
Returns null if if the argument will never accepted.
-
getZoomlevelRangeOpenWay(ITagCollection tags)
→ ZoomlevelRange?
-
Returns the widest possible zoomrange which may accept the given argument.
Returns null if if the argument will never accepted.
-
matchClosedWay(Way way, Tile tile, List<Renderinstruction> matchingList)
→ void
-
-
matches(TagCollection tags, int indoorLevel)
→ bool
-
Returns true if the rule matches the given tags and indoor level
-
matchesForZoomLevel(int zoomLevel)
→ bool
-
Returns true if this rule can be applied for the given zoomLevel.
-
matchesTags(ITagCollection tags)
→ bool
-
Checks the tags if the rule matches, does NOT take the indoorLevel into account.
-
matchNode(int indoorLevel, List<Renderinstruction> matchingList, PointOfInterest pointOfInterest)
→ void
-
-
matchOpenWay(Way way, Tile tile, List<Renderinstruction> matchingList)
→ void
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
onComplete()
→ void
-
-
searchForSymbolBoundary(String id)
→ MapRectangle?
-
Searches for the boundary of a symbol denoted by the given
id. Returns null if the symbol is not found.
override
-
secondPass()
→ void
-
-
toString()
→ String
-
A string representation of this object.
override